OC.L10N.register(
    "mail",
    {
    "Embedded message %s" : "Вградено съобщение %s",
    "Important mail" : "Важна поща",
    "No message found yet" : "Все още няма намерено съобщение",
    "Set up an account" : "Създаване на профил",
    "Unread mail" : "Непрочетена поща",
    "Important" : "Важно",
    "Work" : "Служебен",
    "Personal" : "Личен",
    "To Do" : "Задачи",
    "Later" : "По-късно",
    "Mail" : "Поща",
    "You are currently using {percentage} of your mailbox storage. Please make some space by deleting unneeded emails." : "В момента използвате {percentage}от квотата на пощенската си кутия. Моля, освободете пространство като изтриете ненужни съобщения.",
    "Mails" : "Пощи",
    "💌 A mail app for Nextcloud" : "💌 Приложение за поща за Nextcloud",
    "Your session has expired. The page will be reloaded." : "Сесията ви е изтекла. Страницата ще бъде заредена отново.",
    "Drafts are saved in:" : "Черновите са записани в:",
    "Sent messages are saved in:" : "Изпратените съобщения се запазват в:",
    "Deleted messages are moved in:" : "Изтритите съобщения се преместват в:",
    "Archived messages are moved in:" : "Архивираните съобщения са преместени в:",
    "Connecting" : "Свързване",
    "Reconnect Google account" : "Повторно свързване на профил в Google",
    "Sign in with Google" : "Вписване с Google",
    "Save" : "Запис",
    "Connect" : "Свържи",
    "Looking up configuration" : "Търсене на конфигурация",
    "Checking mail host connectivity" : "Проверка на сврзаност с пощенския сървър",
    "Configuration discovery failed. Please use the manual settings" : "Неуспешно откриване на конфигурация. Моля, използвайте ръчните настройки",
    "Password required" : "Паролата е задължителна",
    "Testing authentication" : "Тестване на удостоверяване",
    "Awaiting user consent" : "Очаква се съгласието на потребителя",
    "Loading account" : "Зареждане на профил",
    "Account updated" : "Профилът е актуализиран",
    "IMAP server is not reachable" : "IMAP сървърът не е достъпен",
    "SMTP server is not reachable" : "SMTP IMAP сървърът не е достъпен",
    "IMAP username or password is wrong" : "Грешно IMAP име на потребител или парола",
    "SMTP username or password is wrong" : "Грешно SMTP име на потребител или парола",
    "IMAP connection failed" : "IMAP връзката прекъсна",
    "SMTP connection failed" : "SMTP връзката прекъсна",
    "Authorization pop-up closed" : "Затворен е изскачащият прозорец за оторизация",
    "There was an error while setting up your account" : "Възникна грешка при настройката на вашия профил",
    "Auto" : "Автоматично",
    "Name" : "Име",
    "Mail address" : "Имейл адрес",
    "name@example.org" : "name@example.org",
    "Please enter an email of the format name@example.com" : "Моля, въведете имейл в следният формат: name@example.com",
    "Password" : "Парола",
    "Manual" : "Ръчно",
    "IMAP Settings" : "IMAP настройки",
    "IMAP Host" : "IMAP сървър",
    "IMAP Security" : "IMAP сигурност",
    "None" : "Няма",
    "SSL/TLS" : "SSL/TLS",
    "STARTTLS" : "STARTTLS",
    "IMAP Port" : "IMAP порт",
    "IMAP User" : "IMAP потребител",
    "IMAP Password" : "IMAP парола",
    "SMTP Settings" : "SMTP настройки",
    "SMTP Host" : "SMTP сървър",
    "SMTP Security" : "SMTP сигурност",
    "SMTP Port" : "SMTP порт",
    "SMTP User" : "SMTP потребител",
    "SMTP Password" : "SMTP парола",
    "For the Google account to work with this app you need to enable two-factor authentication for Google and generate an app password." : "За да може Google профил да работи с това приложение, трябва да активирате двустепенно удостоверяване за Google и да генерирате парола за приложението.",
    "Account settings" : "Настройки на профила",
    "Aliases" : "Псевдоними",
    "Alias to S/MIME certificate mapping" : "Съпоставка на псевдоним със S/MIME сертификат",
    "Signature" : "Подпис",
    "A signature is added to the text of new messages and replies." : "Подписът се добавя в края на текста, на изходящите съобщения.",
    "Writing mode" : "Режим на писане",
    "Preferred writing mode for new messages and replies." : "Предпочитан режим на писане за нови съобщения и отговори.",
    "Default folders" : "Папки по подразбиране",
    "Autoresponder" : "Автоматичен отговор",
    "Automated reply to incoming messages. If someone sends you several messages, this automated reply will be sent at most once every 4 days." : "Автоматичен отговор на входящите съобщения. Ако някой ви изпрати няколко съобщения, този автоматичен отговор ще бъде изпращан най-много веднъж на всеки 4 дни.",
    "Filters" : "Филтри",
    "Mail server" : "Имейл сървър",
    "Update alias" : "Актуализиране на псевдоним",
    "Rename alias" : "Преименуване на псевдоним",
    "Show update alias form" : "Показване на формуляр за актуализиране на псевдоним",
    "Delete alias" : "Изтриване на псевдоним",
    "Go back" : "Назад",
    "Change name" : "Промяна на име",
    "Email address" : "Имейл адрес",
    "Add alias" : "Добавяне на псевдоним",
    "Create alias" : "Създаване на псевдоним",
    "Cancel" : "Отказ",
    "Put my text to the bottom of a reply instead of on top of it." : "Поставяне на моя текст в долната част на отговора, вместо над него.",
    "Could not update preference" : "Предпочитанието не можа да се актуализира",
    "Mail settings" : "Настройки на пощата",
    "Accounts" : "Профили",
    "Add mail account" : "Добавяне на профил",
    "General" : "Общи",
    "List" : "Списък",
    "Newest" : "Най-новият",
    "Oldest" : "Най-старият",
    "Use Gravatar and favicon avatars" : "Използване на аватари тип Gravatar и favicon",
    "Register as application for mail links" : "Регистрирайте се като приложение за пощенски връзки",
    "Register" : "Регистрация",
    "Shared with me" : "Споделено с мен",
    "Allow the app to collect data about your interactions. Based on this data, the app will adapt to your preferences. The data will only be stored locally." : "Разрешаване на приложението да събира данни за вашите взаимодействия. Въз основа на тези данни приложението ще се адаптира към вашите предпочитания. Данните ще се съхраняват само локално.",
    "Trusted senders" : "Доверени податели",
    "Manage S/MIME certificates" : "Управление на S/MIME сертификати",
    "About" : "Относно",
    "Keyboard shortcuts" : "Бързи клавиши",
    "Compose new message" : "Създай ново съобщение",
    "Newer message" : "Следващо съобщение",
    "Older message" : "Предишно съобщение",
    "Toggle star" : "Означи със/Премахни звезда",
    "Toggle unread" : "Означи като (не)/прочетено",
    "Archive" : "Архивиране",
    "Delete" : "Изтриване",
    "Search" : "Търси",
    "Send" : "Изпрати",
    "Refresh" : "Опресняване",
    "Ok" : "Добре",
    "No certificate" : "Няма сертификат",
    "Certificate updated" : "Актуализиран е сертификат",
    "Could not update certificate" : "Сертификата не можа да се актуализира",
    "{commonName} - Valid until {expiryDate}" : "{commonName} - Валидно до {expiryDate}",
    "Select an alias" : "Избор на псевдоним",
    "Update Certificate" : "Актуализиране на сертификат",
    "Encrypt with S/MIME and send later" : "Криптиране със S/MIME и изпращане по-късно",
    "Encrypt with S/MIME and send" : "Криптиране със S/MIME и изпращане",
    "Encrypt with Mailvelope and send later" : "Криптиране с Mailvelope и изпращане по-късно",
    "Encrypt with Mailvelope and send" : "Криптиране с Mailvelope и изпращане",
    "Send later" : "Изпратете по-късно",
    "Message {id} could not be found" : "Съобщението {id} не можа да бъде намерено",
    "Sign or Encrypt with S/MIME was selected, but we don't have a certificate for the selected alias. The message will not be signed or encrypted." : "Избрано е подписване или криптиране със S/MIME, но нямаме сертификат за избрания псевдоним. Съобщението няма да бъде подписано или криптирано.",
    "Any existing formatting (for example bold, italic, underline or inline images) will be removed." : "Всяко съществуващо форматиране (например удебеляване, курсив, подчертани или вградени изображения) ще бъде премахнато.",
    "Turn off formatting" : "Изключване на форматирането",
    "Turn off and remove formatting" : "Изключване и премахване на форматирането",
    "Keep formatting" : " Запазване /продължаване/ на форматирането",
    "From" : "От",
    "Select account" : "Избери профил",
    "To" : "До",
    "Select recipient" : "Избор на получател",
    "Contact or email address …" : "Контакт или имейл адрес...",
    "Cc" : "Cc",
    "Bcc" : "Bcc",
    "Subject" : "Тема",
    "Subject …" : "Тема...",
    "This message came from a noreply address so your reply will probably not be read." : "Това съобщение дойде от адрес с настройка без отговор, така че отговорът ви вероятно няма да бъде прочетен.",
    "The following recipients do not have a S/MIME certificate: {recipients}." : "Следните получатели нямат  S/MIME сертификат: {recipients}.",
    "The following recipients do not have a PGP key: {recipients}." : "Следните получатели нямат PGP ключ: {recipients}.",
    "Write message …" : "Писане на съобщение ...",
    "Saving draft …" : "Записване на чернова …",
    "Error saving draft" : "Грешка при запазване на черновата",
    "Draft saved" : "Черновата е записана",
    "Save draft" : "Запиши чернова",
    "Discard & close draft" : "Отхвърляне и затворяне на черновата",
    "Enable formatting" : "Форматиран текст",
    "Disable formatting" : "Деактивиране на форматирането",
    "Upload attachment" : "Прикачи файл",
    "Add attachment from Files" : "Прикачи от \"Файлове\"",
    "Add share link from Files" : "Сподели връзка от \"Файлове\"",
    "Smart picker" : "Умно избиране",
    "Request a read receipt" : "Заявка на разписка за прочитане",
    "Sign message with S/MIME" : "Подписване на съобщение със S/MIME/сертификат/",
    "Encrypt message with S/MIME" : "Криптиране на съобщение със S/MIME",
    "Encrypt message with Mailvelope" : "Криптиране на съобщение с Mailvelope",
    "Send now" : "Изпратете сега",
    "Tomorrow morning" : "Утре сутрин",
    "Tomorrow afternoon" : "Утре следобед",
    "Monday morning" : "Понеделник сутрин",
    "Custom date and time" : "Персонализирана дата и час",
    "Enter a date" : "Въведете дата",
    "Choose" : "Изберете",
    "_The attachment exceed the allowed attachments size of {size}. Please share the file via link instead._::_The attachments exceed the allowed attachments size of {size}. Please share the files via link instead._" : ["Прикачените файлове надвишават разрешения размер на прикачени файлове от {size}. Моля, вместо това да споделите файловете чрез връзка.","Прикачените файлове надвишават разрешения размер на прикачени файлове от {size}. Моля, вместо това да споделите файловете чрез връзка."],
    "Choose a file to add as attachment" : "Избери файл за прикачване",
    "Choose a file to share as a link" : "Изберете файл, който да споделите като връзка",
    "_{count} attachment_::_{count} attachments_" : ["{count} прикачени файлове","{count} прикачени файлове"],
    "Confirm" : "Потвърдете",
    "Plain text" : "Обикновен текст",
    "Rich text" : "Форматиран текст",
    "No messages in this folder" : "Няма съобщения",
    "No messages" : "Няма съобщения.",
    "Blind copy recipients only" : "Само получателите на слепи копия",
    "No subject" : "Без /няма/ тема",
    "Later today – {timeLocale}" : "По-късно днес - {timeLocale}",
    "Tomorrow – {timeLocale}" : "Утре - {timeLocale}",
    "This weekend – {timeLocale}" : "Този уикенд - {timeLocale}",
    "Next week – {timeLocale}" : "Следващата седмица - {timeLocale}",
    "Could not delete message" : "Съобщението не може да бъде изтрито",
    "Could not archive message" : "Не можа да се архивира съобщение",
    "Encrypted message" : "Криптирано съобщение",
    "This message is unread" : "Това съобщение не е прочетено",
    "Unfavorite" : "Премахване от Любими",
    "Favorite" : "Любими",
    "Unread" : "Непрочетено",
    "Read" : "Прочитане",
    "Unimportant" : "Маловажно",
    "Mark not spam" : "Маркиране, че не е спам",
    "Mark as spam" : "Маркирай като спам",
    "Edit tags" : "Редактиране на етикетите",
    "Move thread" : "Преместване на нишката",
    "Archive thread" : "Архивна нишка",
    "Archive message" : "Архивиране на съобщение",
    "Delete thread" : "Изтриване на нишката",
    "Delete message" : "Изтриване на съобщението",
    "More actions" : "Повече действия",
    "Back" : "Назад",
    "Edit as new message" : "Редактиране като ново съобщение",
    "Create task" : "Създаване на задача",
    "Download message" : "Изтегляне на съобщение",
    "Load more" : "Зареждане на още",
    "_Mark {number} read_::_Mark {number} read_" : ["Маркиране {number} прочетено","Маркиране {number} прочетено"],
    "_Mark {number} unread_::_Mark {number} unread_" : ["Маркиране {number} непрочетено","Маркиране {number} непрочетено"],
    "_Mark {number} as important_::_Mark {number} as important_" : ["Маркиране на {номер} като важен","Маркиране на {номер} като важен"],
    "_Mark {number} as unimportant_::_Mark {number} as unimportant_" : ["Маркиране на {номер} като маловажен","Маркиране на {номер} като маловажен"],
    "_Unfavorite {number}_::_Unfavorite {number}_" : ["Премахване от любими {number}","Премахване от любими {number}"],
    "_Favorite {number}_::_Favorite {number}_" : ["Любими {number}","Любими {number}"],
    "_Unselect {number}_::_Unselect {number}_" : ["Любими {number}"," Отмяна на избора {number}"],
    "_Mark {number} as spam_::_Mark {number} as spam_" : ["Маркирай {number} като спам","Маркирай {number} като спам"],
    "_Mark {number} as not spam_::_Mark {number} as not spam_" : ["{number} не са спам","{number}не е спам "],
    "_Move {number} thread_::_Move {number} threads_" : ["Преместване на {number} нишки","Преместване на {number} нишки"],
    "_Forward {number} as attachment_::_Forward {number} as attachment_" : ["Препращане {number} като прикачен файл","Препращане {number} като прикачен файл"],
    "Mark as unread" : "Маркиране като непрочетено",
    "Mark as read" : "Маркиране като прочетено",
    "Report this bug" : "Докладване на тази грешка",
    "Event created" : "Събитието е създадено",
    "Could not create event" : "Несупешно създаване на събитие",
    "Create event" : "Създаване на събитие",
    "All day" : "Цял ден",
    "Attendees" : "Участници",
    "Description" : "Описание",
    "Create" : "Създаване",
    "This event was updated" : "Това събитие беше актуализирано",
    "{attendeeName} accepted your invitation" : "{attendeeName} прие вашата покана",
    "{attendeeName} tentatively accepted your invitation" : "{attendeeName} прие вашата покана условно",
    "{attendeeName} declined your invitation" : "{attendeeName} е отхвърлил поканата ви",
    "{attendeeName} reacted to your invitation" : "{attendeeName} реагира на вашата покана",
    "Failed to save your participation status" : "Неуспешно записване на статуса ви на участие",
    "You accepted this invitation" : "Приехте тази покана",
    "You tentatively accepted this invitation" : "Вие приехте тази покана условно",
    "You declined this invitation" : "Отхвърлихте поканата",
    "You already reacted to this invitation" : "Вие вече реагирахте на тази покана",
    "You have been invited to an event" : "Поканени сте на събитие",
    "This event was cancelled" : "Това събитие беше отказано",
    "Save to" : "Запиши в",
    "Select" : "Избери",
    "Comment" : "Коментар",
    "Accept" : "Приемам",
    "Decline" : "Отхвърляне",
    "Tentatively accept" : "Приемам условно",
    "More options" : "Още опции",
    "individual" : "Индивидуален",
    "domain" : "домейн",
    "Remove" : "Премахване",
    "email" : "имейл",
    "Itinerary for {type} is not supported yet" : "Маршрутът за {type} все още не се поддържа",
    "You are not allowed to move this message to the archive folder and/or delete this message from the current folder" : "Нямате право да преместите това съобщение в архивната папка и/или да изтриете това съобщение от текущата папка",
    "Last hour" : "Последния  час",
    "Today" : "Днес",
    "Last week" : "Миналата седмица",
    "Last month" : "Миналия месец",
    "Loading messages …" : "Зареждане на съобщения ...",
    "Choose target folder" : "Избор на папка",
    "No more submailboxes in here" : "Тук няма повече допълнителни пощенски кутии",
    "Messages will automatically be marked as important based on which messages you interacted with or marked as important. In the beginning you might have to manually change the importance to teach the system, but it will improve over time." : "Съобщенията автоматично ще бъдат маркирани като важни въз основа на съобщенията, с които сте взаимодействали или маркирани като важни. В началото може да се наложи ръчно да промените важността, за да обучите системата, но тя ще се подобри с течение на времето.",
    "Important info" : "Важна информация",
    "Other" : "Друг",
    "Could not send mdn" : "Не можа да се изпрати mdn",
    "The sender of this message has asked to be notified when you read this message." : "Подателят на това съобщение поиска да бъде уведомен, когато прочетете това съобщение.",
    "Notify the sender" : "Уведомяване на подателя",
    "You sent a read confirmation to the sender of this message." : "Изпратихте потвърждение за четене на подателя на това съобщение.",
    "Forward" : "Напред",
    "Move message" : "Преместване на съобщението",
    "Translate" : "Превод",
    "Forward message as attachment" : "Препращане на съобщението като прикачен файл",
    "View source" : "Преглед на източника",
    "Download thread data for debugging" : "Изтегля данните за нишките за отстраняване на грешки",
    "Message body" : "Тяло на съобщението",
    "Warning: The S/MIME signature of this message is unverified. The sender might be impersonating someone!" : "Предупреждение: S/MIME подписът на това съобщение не е потвърден. Възможно е подателят да се представя /въплъщава/ за някого!",
    "Unnamed" : "Без име",
    "Embedded message" : "Вградено съобщение",
    "Choose a folder to store the attachment in" : "Избери папка, където да бъде запазен прикаченият файл",
    "Import into calendar" : "Импортиране в календар",
    "Download attachment" : "Изтегли прикачените файлове",
    "Save to Files" : "Запази във Файлове",
    "View fewer attachments" : "Вижте по-малко прикачени файлове",
    "Choose a folder to store the attachments in" : "Избор на папка, където да бъдат запазени прикачените файлове",
    "Save all to Files" : "Записване на всички към Файлове",
    "Download Zip" : "Изтегляне на Zip",
    "_View {count} more attachment_::_View {count} more attachments_" : ["Вижте още {count} прикачени файлове","Вижте още {count} прикачени файлове"],
    "This message is encrypted with PGP. Install Mailvelope to decrypt it." : "Това съобщение е шифровано с PGP. Инсталирайте Mailvelope, за да го дешифрирате.",
    "The images have been blocked to protect your privacy." : "Изображенията са блокирани, за да защитят поверителността ви.",
    "Show images" : "Покажи снимките",
    "Show images temporarily" : "Временно показване на изображения",
    "Always show images from {sender}" : "Винаги да се показват изображения от {sender}",
    "Always show images from {domain}" : "Винаги да се показват изображения от {domain}",
    "Message frame" : "Рамка на съобщението",
    "Quoted text" : "Цитиран текст",
    "Move" : "Преместване",
    "Moving" : "Преместване ",
    "Moving thread" : "Нишката се премества",
    "Moving message" : "Съобщението се премества",
    "Remove account" : "Изтриване",
    "The account for {email} and cached email data will be removed from Nextcloud, but not from your email provider." : "Профилът за {email} и кешираните имейл данни ще бъдат премахнати от Nextcloud, но не и от вашия доставчик на електронна поща.",
    "Remove {email}" : "Премахване {email}",
    "Provisioned account is disabled" : "Осигуреният профил е деактивиран",
    "Please login using a password to enable this account. The current session is using passwordless authentication, e.g. SSO or WebAuthn." : "Моля, да се впишете с парола, за да активирате този профил. Текущата сесия използва удостоверяване без парола, напр. SSO или WebAuthn.",
    "Add folder" : "Добави папка",
    "Folder name" : "Име на папка",
    "Saving" : "Запазване",
    "Move up" : "Преместване нагоре",
    "Move down" : "Преместване  надолу",
    "Show all folders" : "Покажи всички папки",
    "Collapse folders" : "Свиване на папки",
    "_{total} message_::_{total} messages_" : ["{total} съобщения","{total} съобщения"],
    "_{unread} unread of {total}_::_{unread} unread of {total}_" : ["{unread} непрочетени от {total}","{unread} непрочетени от {total}"],
    "Loading …" : "Зарежда …",
    "All messages in mailbox will be deleted." : "Всички съобщения в пощенската кутия ще бъдат изтрити.",
    "Clear mailbox {name}" : "Изчистване на пощенска кутия {name}",
    "Delete folder" : "Изтриване на папка",
    "An error occurred, unable to rename the mailbox." : "Възникна грешка, не можа да се преименува пощенската кутия.",
    "Mark all as read" : "Маркирай всички като прочетени",
    "Mark all messages of this folder as read" : "Маркирай всички съобщения в папката като прочетени",
    "Add subfolder" : "Добави подпапка",
    "Rename" : "Преименуване",
    "Move folder" : "Преместване на папка",
    "Clear cache" : "Изтриване на кеша",
    "Clear locally cached data, in case there are issues with synchronization." : "Изчистете локално кеширани данни, в случай че има проблеми със синхронизирането.",
    "Subscribed" : "Абониран",
    "Sync in background" : "Синхронизиране във фонов режим",
    "Outbox" : "Изходящи",
    "New message" : "Ново съобщение",
    "Edit message" : "Редактиране на съобщение",
    "Draft" : "Чернова",
    "Reply" : "Отговори",
    "You are trying to send to many recipients in To and/or Cc. Consider using Bcc to hide recipient addresses." : "Опитвате се да изпратите до много получатели в полето До и/или Копие. Помислете за използването на Bcc, за да скриете адресите на получателите.",
    "Message discarded" : "Съобщението е отхвърлено",
    "Could not discard message" : "Съобщението не можа да бъде отхвърлено",
    "Error sending your message" : "Грешка при изпращне на вашето съобщение.",
    "Retry" : "Опитай отново",
    "Warning sending your message" : "Предупреждение за изпращане на вашето съобщение",
    "Send anyway" : " Все пак го изпратете",
    "Autoresponder off" : "Автоматичният отговор е изключен",
    "Autoresponder on" : "Автоматичният отговор е включен",
    "Edit absence settings" : "Промени настройките на отсъствието",
    "First day" : "От",
    "Last day (optional)" : "Последен ден (по избор)",
    "${subject} will be replaced with the subject of the message you are responding to" : "${subject} ще бъде заменена с темата на съобщението, на което отговаряте",
    "Message" : "Съобщение",
    "Oh Snap!" : "О, не!",
    "Save autoresponder" : "Записване на автоматичен отговор",
    "Could not open outbox" : "Не можаха да се отворят изходящите",
    "Pending or not sent messages will show up here" : "Чакащи или неизпратени съобщения ще се показват тук",
    "Message could not be sent" : "Съобщението не можа да бъде изпратено",
    "Message deleted" : "Съобщението е изтрито ",
    "Copied email address to clipboard" : "Копиран е имейл адрес в клипборда",
    "Could not copy email address to clipboard" : "Неуспешно копиране на имейл адреса в клипборда",
    "Contacts with this address" : "Контакти с този адрес",
    "Add to Contact" : "Добавяне към контакт",
    "New Contact" : "Нов контакт",
    "Copy to clipboard" : "Копиране в клипборда",
    "Contact name …" : "Име за контакт …",
    "Add" : "Добавяне",
    "Show less" : "Покажи по-малко",
    "Show more" : "Покажи повече",
    "Clear" : "Изчистване",
    "Close" : "Затваряне",
    "Search parameters" : "Параметри на търсенето",
    "Body" : "Съдържание",
    "Date" : "Дата",
    "Pick a start date" : "Избор на начална дата",
    "Pick an end date" : "Избор на крайна дата",
    "Select senders" : "Избор на податели",
    "Select recipients" : "Избор на получатели",
    "Select CC recipients" : "Избор на CC получатели",
    "Select BCC recipients" : "Избор на BCC получатели",
    "Tags" : "Етикети",
    "Select tags" : "Избор на етикети",
    "Marked as" : "Маркиран/о като",
    "Has attachments" : "Има прикачени файлове",
    "Last 7 days" : "Последни 7 дни",
    "Sieve Port" : "Порт на Сито",
    "Custom" : "Персонализиран",
    "Sieve User" : "Потребител на Сито",
    "Sieve Password" : "Парола за Сито",
    "Save sieve settings" : "Записване на настройките на ситото",
    "Save sieve script" : "Записване на скрипт за сито",
    "Signature …" : "Подпис…",
    "Your signature is larger than 2 MB. This may affect the performance of your editor." : "Подписът ви е по-голям от 2 MB. Това може да се отрази на работата на  вашия редактор.",
    "Save signature" : "Запис на подпис",
    "Place signature above quoted text" : "Поставяне на подпис над цитирания текст",
    "Message source" : "Източник на съобщение",
    "An error occurred, unable to rename the tag." : "Възникна грешка, не може да се преименува етикет.",
    "Saving new tag name …" : "Запазва се името на нов етикет …",
    "Delete tag" : "Изтрий таг",
    "Set tag" : "Задаване на етикет",
    "Unset tag" : "Отмяна на етикет",
    "Tag name is a hidden system tag" : "Името на етикета е скрит системен етикет",
    "Tag already exists" : "Етикетът вече съществува",
    "An error occurred, unable to create the tag." : "Възникна грешка, не може да се създаде етикет.",
    "Add default tags" : "Добавяне на етикети по подразбиране",
    "Add tag" : "Добавяне на етикет",
    "Saving tag …" : "Записване на етикет ...",
    "Could not load your message thread" : " Нишката на вашето съобщение не можа да се зареди",
    "The thread doesn't exist or has been deleted" : "Нишката не съществува или е била изтрита",
    "Loading thread" : "Зареждане на нишка",
    "Not found" : "Не е намерен",
    "Encrypted & verified " : "Криптирано и потвърдено",
    "Signature verified" : "Подписът е потвърден",
    "Signature unverified " : "Подписът не е потвърден",
    "This message was encrypted by the sender before it was sent." : "Това съобщение е било криптирано от изпращача преди да бъде изпратено.",
    "This message contains a verified digital S/MIME signature. The message wasn't changed since it was sent." : "Това съобщение съдържа проверен цифров подпис S/MIME. Съобщението не е променяно след изпращането му.",
    "This message contains an unverified digital S/MIME signature. The message might have been changed since it was sent or the certificate of the signer is untrusted." : "Това съобщение съдържа непроверен цифров S/MIME подпис. Възможно е съобщението да е било променено, след както е изпратено, или сертификатът на подписаният да е ненадежден.",
    "Reply all" : "Отговаряне на всички",
    "Unsubscribe" : "Отписване",
    "Reply to sender only" : "Отговор само на подателя",
    "Mark as unfavorite" : "Маркиране като непредпочитано",
    "Mark as favorite" : "Маркиране като любими",
    "Unsubscribing will stop all messages from the mailing list {sender}" : "Прекратяването на абонамента ще спре всички съобщения от пощенския списък {sender}",
    "Could not remove trusted sender {sender}" : "Не можа да бъде премахнат доверен подател {sender}",
    "No senders are trusted at the moment." : "В момента няма доверени податели.",
    "Untitled event" : "Събитие без заглавие",
    "(organizer)" : "(организатор)",
    "Import into {calendar}" : "Импортиране в {calendar}",
    "Event imported into {calendar}" : "Събитието е импортирано в {calendar}",
    "Flight {flightNr} from {depAirport} to {arrAirport}" : "Полет {flightNr} от {depAirport} до {arrAirport}",
    "Airplane" : "Самолет",
    "Reservation {id}" : "Резервация {id}",
    "{trainNr} from {depStation} to {arrStation}" : "{trainNr} от {depStation} до {arrStation}",
    "Train from {depStation} to {arrStation}" : "Влак от {depStation} до {arrStation}",
    "Train" : "Влак",
    "Recipient" : "Получател",
    "contains" : "съдържа",
    "matches" : "съвпадения",
    "Priority" : "Приоритет",
    "Tag" : "Етикет",
    "delete" : "изтриване",
    "Edit" : "Промяна",
    "Successfully updated config for \"{domain}\"" : "Конфигурацията за „{domain}“ беше актуализирана успешно",
    "Error saving config" : "Грешка при записване на конфигурацията",
    "Saved config for \"{domain}\"" : "Конфигурацията за „{domain}“ е записана",
    "Could not save provisioning setting" : "Настройката за осигуряване не можа да бъде записана",
    "_Successfully provisioned {count} account._::_Successfully provisioned {count} accounts._" : ["Успешно осигурени {count} профили.","Успешно осигурени {count} профили."],
    "There was an error when provisioning accounts." : "Възникна грешка при осигуряването на профили.",
    "Successfully deleted and deprovisioned accounts for \"{domain}\"" : "Успешно изтрити и неосигурени профили за „{domain}“",
    "Error when deleting and deprovisioning accounts for \"{domain}\"" : "Грешка при изтриване и неосигуряване на профили за „{domain}“",
    "Mail app" : "Приложение за поща",
    "The mail app allows users to read mails on their IMAP accounts." : "Приложението за поща позволява на потребителите да четат имейли в своите IMAP профили.",
    "Here you can find instance-wide settings. User specific settings are found in the app itself (bottom-left corner)." : "Тук можете да намерите настройки за целия екземпляр. Потребителските настройки се намират в самото приложение (долния ляв ъгъл).",
    "Account provisioning" : "Осигуряване на профил",
    "A provisioning configuration will provision all accounts with a matching email address." : "Конфигурацията за осигуряване ще предостави на всички профили съответстващ имейл адрес.",
    "Using the wildcard (*) in the provisioning domain field will create a configuration that applies to all users, provided they do not match another configuration." : "Използването на заместващия символ (*) в полето на домейн за осигуряване, ще създаде конфигурация, която се прилага за всички потребители, при условие че не съвпадат с друга конфигурация.",
    "The provisioning mechanism will prioritise specific domain configurations over the wildcard domain configuration." : "Механизмът за осигуряване ще даде приоритет на конкретни конфигурации на домейни пред конфигурацията на домейн със заместващи символи.",
    "Should a new matching configuration be found after the user was already provisioned with another configuration, the new configuration will take precedence and the user will be reprovisioned with the configuration." : "Ако бъде намерена нова съответстваща конфигурация, след като потребителят вече е бил осигурен с друга конфигурация, новата конфигурация ще има предимство и потребителят ще бъде повторно обезпечен с конфигурацията.",
    "There can only be one configuration per domain and only one wildcard domain configuration." : "Може да има само една конфигурация на домейн и само една конфигурация на домейн със заместващи символи.",
    "These settings can be used in conjunction with each other." : "Тези настройки могат да се използват свързани една с друга.",
    "If you only want to provision one domain for all users, use the wildcard (*)." : "Ако искате да осигурите само един домейн за всички потребители, използвайте заместващия символ (*).",
    "This setting only makes most sense if you use the same user back-end for your Nextcloud and mail server of your organization." : "Тази настройка има най-голям смисъл само ако използвате същия потребителски вътрешен сървър за вашия Nextcloud и пощенски сървър на вашата организация.",
    "Provisioning Configurations" : "Конфигурации за осигуряване",
    "Add new config" : "Добавяне на нова конфигурация",
    "Provision all accounts" : "Осигуряване на всички профили",
    "Allow additional mail accounts" : "Разрешаване на допълнителни пощенски профили",
    "Allow additional Mail accounts from User Settings" : "Разрешаване на допълнителни пощенски профили от настройките на потребителя",
    "Anti Spam Service" : "Услуга за защита от нежелана поща",
    "You can set up an anti spam service email address here." : "Можете да настроите имейл адрес за услуга за защита от нежелана поща тук.",
    "Any email that is marked as spam will be sent to the anti spam service." : "Всеки имейл, който е маркиран като нежелана поща, ще бъде изпратен до услугата за защита от нежелана поща.",
    "Gmail integration" : "Gmail интеграция",
    "Gmail allows users to access their email via IMAP. For security reasons this access is only possible with an OAuth 2.0 connection or Google accounts that use two-factor authentication and app passwords." : "Gmail позволява на потребителите да имат достъп до електронната си поща чрез IMAP. От съображения за сигурност този достъп е възможен само с връзка OAuth 2.0 или профили в Google, които използват двустепенно удостоверяване и пароли за приложения.",
    "You have to register a new Client ID for a \"Web application\" in the Google Cloud console. Add the URL {url} as authorized redirect URI." : "Трябва да регистрирате нов клиентски идентификатор за \"уеб приложение\" в конзолата на облачното пространство Google Cloud. Добавете URL {url} като оторизиран URI за пренасочване.",
    "Microsoft integration" : "Microsoft интеграция",
    "Successfully set up anti spam email addresses" : "Успешно настроени имейл адреси срещу нежелана поща",
    "Error saving anti spam email addresses" : "Грешка при записване на имейл адреси срещу нежелана поща",
    "Successfully deleted anti spam reporting email" : "Успешно изтрит имейл за сигнали срещу нежелана поща",
    "Error deleting anti spam reporting email" : "Грешка при изтриването на имейл за сигнали срещу нежелана поща",
    "Anti Spam" : "Защита от нежелана поща",
    "Add the email address of your anti spam report service here." : "Добавяне на имейл адреса на вашата услуга за докладване на нежелана поща тук.",
    "When using this setting, a report email will be sent to the SPAM report server when a user clicks \"Mark as spam\"." : "Когато използвате тази настройка, имейл с отчет ще бъде изпратен до сървъра за отчети за НЕЖЕЛАНА ПОЩА, когато потребителят щракне върху „Маркиране като нежелана поща“.",
    "The original message will be attached as a \"message/rfc822\" attachment." : "Оригиналното съобщение ще бъде прикачено като прикачен файл \"message/rfc822\".",
    "\"Mark as Spam\" Email Address" : "Имейл адрес „Маркиране като нежелана поща“.",
    "\"Mark Not Junk\" Email Address" : "Имейл адрес „Маркиране, че не е отпадък“.",
    "Reset" : "Възстановяване",
    "Google integration configured" : "Конфигурирана е интеграция с Google",
    "Could not configure Google integration" : "Не можа да се конфигурира интеграцията на Google",
    "Google integration unlinked" : "Премахната е връзката с интеграцията на Google",
    "Could not unlink Google integration" : "Не можа да се премахне връзката с интеграцията на Google",
    "Client ID" : "Идентификатор на клиент",
    "Client secret" : "Тайна на клиент",
    "Unlink" : "Прекратяване на връзката",
    "Microsoft integration configured" : "Конфигурирана е интеграцията на Microsoft",
    "Could not configure Microsoft integration" : "Не можа да се конфигурира интеграцията на Microsoft",
    "Microsoft integration unlinked" : "Премахната е връзката с интеграцията на Microsoft",
    "Could not unlink Microsoft integration" : " Не можа да се премахне връзката с интеграцията на Microsoft",
    "Tenant ID (optional)" : "Идентификатор на клиент (по избор)",
    "Domain Match: {provisioningDomain}" : "Съвпадение на домейна: {provisioningDomain}",
    "Email: {email}" : "Имейл: {email}",
    "IMAP: {user} on {host}:{port} ({ssl} encryption)" : "IMAP: {user} на {host}:{port} ({ssl} криптиране)",
    "SMTP: {user} on {host}:{port} ({ssl} encryption)" : "SMTP: {user} на {host}:{port} ({ssl} криптиране)",
    "Sieve: {user} on {host}:{port} ({ssl} encryption)" : "Сито: {user} на {host}:{port} ({ssl} криптиране)",
    "Configuration for \"{provisioningDomain}\"" : "Конфигурация за „{provisioningDomain}“",
    "Provisioning domain" : "Осигуряващ домейн",
    "Email address template" : "Шаблон за имейл адрес",
    "IMAP" : "IMAP",
    "Host" : "Хост",
    "Port" : "Порт",
    "SMTP" : "SMTP",
    "Sieve" : "Сито",
    "Enable sieve integration" : "Активиране на интегрирането на сито",
    "LDAP aliases integration" : "Интегриране на LDAP псевдоними",
    "Enable LDAP aliases integration" : "Активиране на интеграцията на LDAP псевдоними",
    "The LDAP aliases integration reads an attribute from the configured LDAP directory to provision email aliases." : "Интегрирането на LDAP псевдоними, чете атрибут от конфигурираната LDAP директория, за да осигури имейл псевдоними.",
    "LDAP attribute for aliases" : "LDAP атрибут за псевдоними",
    "A multi value attribute to provision email aliases. For each value an alias is created. Aliases existing in Nextcloud which are not in the LDAP directory are deleted." : "Атрибут с няколко стойности за предоставяне на имейл псевдоними. За всяка стойност се създава псевдоним. Псевдонимите, съществуващи в Nextcloud, които не са в LDAP директорията, се изтриват.",
    "Save Config" : "Записване на конфигурацията",
    "Unprovision & Delete Config" : "Отмяна на осигурявне и изтриване на конфигурация",
    "* %USERID% and %EMAIL% will be replaced with the user's UID and email" : "* %USERID% и %EMAIL% ще бъдат заменени с UID и имейл на потребителя",
    "With the settings above, the app will create account settings in the following way:" : "С настройките по-горе приложението ще създаде настройки на профил по следния начин:",
    "The provided PKCS #12 certificate must contain at least one certificate and exactly one private key." : "Предоставеният сертификат PKCS #12 трябва да съдържа поне един сертификат и само един частен ключ.",
    "Failed to import the certificate. Please check the password." : "Неуспешно импортиране на сертификата. Моля, проверете паролата.",
    "Certificate imported successfully" : "Успешно импортиране на сертификата",
    "Failed to import the certificate. Please make sure that the private key matches the certificate and is not protected by a passphrase." : "Неуспешно импортиране на сертификата. Моля, уверете се, че частният ключ съответства на сертификата и не е защитен с парола.",
    "Failed to import the certificate" : "Неуспешно импортиране на сертификата",
    "S/MIME certificates" : "S/MIME сертификати",
    "Certificate name" : "Име на сертификата",
    "E-mail address" : "Имейл адрес",
    "Valid until" : "Валиден до",
    "Delete certificate" : "Изтриване на сертификат",
    "No certificate imported yet" : "Все още няма импортиран сертификат",
    "Import certificate" : "Импортиране /внасяне/ на сертификат",
    "Import S/MIME certificate" : "Импортиране на S/MIME сертификат",
    "PKCS #12 Certificate" : "Сертификат PKCS #12",
    "PEM Certificate" : "Сертификат PEM",
    "Certificate" : "Сертификат",
    "Private key (optional)" : "Частен ключ (по избор)",
    "The private key is only required if you intend to send signed and encrypted emails using this certificate." : "Частният ключ е необходим само ако възнамерявате да изпращате подписани и криптирани имейли, като използвате този сертификат.",
    "Submit" : "Изпращане",
    "Shared" : "Споделен",
    "Shares" : "Споделени",
    "Insert" : "Вмъкване",
    "Account connected" : "Профилът е свързан",
    "You can close this window" : "Можете да затворите този прозорец",
    "Connect your mail account" : "Свързване към ваш имейл профил",
    "To add a mail account, please contact your administrator." : "Моля да се свържете с вашия администратор, за да добавите пощенски профил.",
    "All" : "Всички",
    "Drafts" : "Чернови",
    "Favorites" : "Любими",
    "Priority inbox" : "Приоритетна папка „Входящи“",
    "All inboxes" : "Всички",
    "Inbox" : "Входящи",
    "Junk" : "Спам",
    "Sent" : "Изпратени",
    "Trash" : "Кошче",
    "Connect OAUTH2 account" : "Свързване на профил OAUTH2",
    "Error while sharing file" : "Грешка при споделяне на файл",
    "{from}\n{subject}" : "{from}\n{subject}",
    "_%n new message \nfrom {from}_::_%n new messages \nfrom {from}_" : ["%n ново съобщение \nот {from}","%n нови съобщения\nот {from}"],
    "Nextcloud Mail" : "Nextcloud Имейл",
    "Attachments were not copied. Please add them manually." : "Прикачените файлове не бяха копирани. Моля, добавете ги ръчно.",
    "Message sent" : "Съобщението е изпратено",
    "Could not send message" : "Не можа да се изпрати съобщение",
    "Could not load {tag}{name}{endtag}" : "{tag}{name}{endtag} не може да бъде зареден",
    "There was a problem loading {tag}{name}{endtag}" : "Проблем при зареждане на {tag}{name}{endtag}",
    "Could not load your message" : "Вашето съобщение не може да бъде заредено",
    "Could not load the desired message" : "Желаното съобщение не може да бъде заредено",
    "Could not load the message" : "Съобщението не може да бъде заредено",
    "Error loading message" : "Грешка при зареждане съобщението",
    "Forwarding to %s" : "Препращане към %s",
    "Click here if you are not automatically redirected within the next few seconds." : "Щракнете тук, ако не бъдете пренасочени автоматично в следващите няколко секунди.",
    "Redirect" : "Пренасочване",
    "The link leads to %s" : "Връзката води до %s",
    "If you do not want to visit that page, you can return to <a href=\"%s\">Mail</a>." : "Ако не желаете да посетите тази страница, може да се върнете към <a href=\"%s\">Поща</a>.",
    "Continue to %s" : "Продължи към %s",
    "Looking for a way to encrypt your emails?" : "Търсите ли начин да шифровате имейлите си?",
    "Install Mailvelope browser extension" : "Инсталирайте разширението за браузър Mailvelope",
    "Flag" : "Знаме",
    "Operator" : "Оператор"
},
"nplurals=2; plural=(n != 1);");
